import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple','lemon'])
	.range(['#c11d1d','#eae600']);

const radiusScale = scaleOrdinal()
	.domain(['apple','lemon'])
	.range([80,50]);

// Render the fruitBowl
export const fruitBowl = (selection, props) => {
  // Deconstruct the props argument
  const { fruits, height } = props;
  
  // Single Element, use data([null])
  const bowl = selection.selectAll('rect')
  	.data([null])
  	.enter().append('rect')
      .attr('y', 110)
      .attr('width',920)
      .attr('height',300)
      .attr('rx',300/2);
 
  // Create a Group Element
  const groups = selection.selectAll('g')
  	.data(fruits, d => d.id);
  const groupsEnter = groups.enter().append('g')
  groupsEnter
    .merge(groups)
  		.attr('transform', (d, i) =>
      	`translate(${i * 180 + 100},${height/2})`);
  groups.exit().remove();
  
  // Append Child Elements to the Group
  groupsEnter.append('circle')
  	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('circle'))
  		.attr('r', d => radiusScale(d.type))
      .attr('fill', d => colorScale(d.type));

  // Append Child Elements to the Group
  groupsEnter.append('text')
  		.attr('y',120)
   	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('text'))
  		.text(d => d.type);
 
}